==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DataSourceSchemaChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceSchemaChangedEventArgsDescription } from "./DataSourceSchemaChangedEventArgsDescription";
/**
 * @hidden
 */
var DataSourceSchemaChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceSchemaChangedEventArgsDescriptionMetadata, _super);
    function DataSourceSchemaChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceSchemaChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DataSourceSchemaChangedEventArgsDescriptionMetadata.a == null) {
            DataSourceSchemaChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceSchemaChangedEventArgsDescriptionMetadata.c(DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(DataSourceSchemaChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceSchemaChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    DataSourceSchemaChangedEventArgsDescriptionMetadata.d = function (a) {
        DataSourceSchemaChangedEventArgsDescriptionMetadata.b(a);
        a.u("DataSourceSchemaChangedEventArgs", function () { return new DataSourceSchemaChangedEventArgsDescription(); });
        a.t("DataSourceSchemaChangedEventArgs", DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceSchemaChangedEventArgsDescriptionMetadata.$t = markType(DataSourceSchemaChangedEventArgsDescriptionMetadata, 'DataSourceSchemaChangedEventArgsDescriptionMetadata');
    DataSourceSchemaChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceSchemaChangedEventArgsDescriptionMetadata;
}(Base));
export { DataSourceSchemaChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DataSourceSchemaChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceSchemaChangedEventArgsDescription } from "./DataSourceSchemaChangedEventArgsDescription";
/**
 * @hidden
 */
var DataSourceSchemaChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceSchemaChangedEventArgsDescriptionMetadata, _super);
    function DataSourceSchemaChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceSchemaChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DataSourceSchemaChangedEventArgsDescriptionMetadata.a == null) {
            DataSourceSchemaChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceSchemaChangedEventArgsDescriptionMetadata.c(DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(DataSourceSchemaChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceSchemaChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    DataSourceSchemaChangedEventArgsDescriptionMetadata.d = function (a) {
        DataSourceSchemaChangedEventArgsDescriptionMetadata.b(a);
        a.aa("DataSourceSchemaChangedEventArgs", function () { return new DataSourceSchemaChangedEventArgsDescription(); });
        a.z("DataSourceSchemaChangedEventArgs", DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceSchemaChangedEventArgsDescriptionMetadata.$t = markType(DataSourceSchemaChangedEventArgsDescriptionMetadata, 'DataSourceSchemaChangedEventArgsDescriptionMetadata');
    DataSourceSchemaChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceSchemaChangedEventArgsDescriptionMetadata;
}(Base));
export { DataSourceSchemaChangedEventArgsDescriptionMetadata };
